@@ -685,8 +685,11 @@ This is a test submission of a new issue.
         self.assertEqual(l, m)
 
         # now with the permission
-        p = self.db.security.getPermission('Create', 'user')
-        self.db.security.role['anonymous'].permissions=[p]
+        p = [
+            self.db.security.getPermission('Create', 'user'),
+            self.db.security.getPermission('Email Access', None),
+        ]
+        self.db.security.role['anonymous'].permissions=p
         self._handle_mail(message)
         m = self.db.user.list()
         m.sort()
